@@ -3,6 +3,13 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 
+class InvalidBinaryException(Exception):
+    """Class for a resource not being found exception."""
+
+    def __init__(self, binary):
+        Exception.__init__(self, ': '.join(["Invalid binary specified", binary]))
+
+
 class NotFoundException(Exception):
     """Class for a resource not being found exception."""
 
@@ -17,7 +24,11 @@ class NotSupportedTestrunException(Exception):
         Exception.__init__(self, 'Testrun not supported: %s' % testrun.__class__.__name__)
 
 class TestFailedException(Exception):
-    """Class for tests failing during a testrun exception"""
-
+    """ Exception for failed tests. """
     def __init__(self):
-        Exception.__init__(self, 'Some tests have been failed.')
+        Exception.__init__(self, "Some tests have failed.")
+
+class TestrunAbortedException(Exception):
+    """ Exception for aborted testrun. """
+    def __init__(self, testrun):
+        Exception.__init__(self, "Testrun aborted: %s" % testrun.__class__.__name__)
